"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault").default;
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Checkbox = void 0;
Object.defineProperty(exports, "CheckboxFacade", {
  enumerable: true,
  get: function () {
    return _CheckboxFacade.CheckboxFacade;
  }
});
Object.defineProperty(exports, "ToggleFacade", {
  enumerable: true,
  get: function () {
    return _ToggleFacade.ToggleFacade;
  }
});
exports.default = void 0;
var _react = require("react");
var _keycode = _interopRequireDefault(require("keycode"));
var _FormFieldMessages = require("@instructure/ui-form-field/lib/FormFieldMessages");
var _createChainedFunction = require("@instructure/ui-utils/lib/createChainedFunction.js");
var _console = require("@instructure/console");
var _isActiveElement = require("@instructure/ui-dom-utils/lib/isActiveElement.js");
var _omitProps = require("@instructure/ui-react-utils/lib/omitProps.js");
var _withDeterministicId = require("@instructure/ui-react-utils/lib/DeterministicIdContext/withDeterministicId.js");
var _View = require("@instructure/ui-view/lib/View");
var _testable = require("@instructure/ui-testable/lib/testable.js");
var _emotion = require("@instructure/emotion");
var _CheckboxFacade = require("./CheckboxFacade");
var _ToggleFacade = require("./ToggleFacade");
var _styles = _interopRequireDefault(require("./styles"));
var _theme = _interopRequireDefault(require("./theme"));
var _props = require("./props");
var _jsxRuntime = require("@emotion/react/jsx-runtime");
var _dec, _dec2, _dec3, _class, _Checkbox;
/*
 * The MIT License (MIT)
 *
 * Copyright (c) 2015 - present Instructure, Inc.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
/**
---
category: components
tags: toggle, switch
---
**/
let Checkbox = exports.Checkbox = (_dec = (0, _withDeterministicId.withDeterministicId)(), _dec2 = (0, _emotion.withStyle)(_styles.default, _theme.default), _dec3 = (0, _testable.testable)(), _dec(_class = _dec2(_class = _dec3(_class = (_Checkbox = class Checkbox extends _react.Component {
  constructor(props) {
    super(props);
    this._defaultId = void 0;
    this._input = null;
    this.ref = null;
    this.handleRef = el => {
      this.ref = el;
    };
    this.handleChange = e => {
      const _this$props = this.props,
        onChange = _this$props.onChange,
        disabled = _this$props.disabled,
        checked = _this$props.checked,
        readOnly = _this$props.readOnly;
      if (disabled || readOnly) {
        e.preventDefault();
        return;
      }
      if (typeof checked === 'undefined') {
        this.setState({
          checked: !this.state.checked
        });
      }
      if (typeof onChange === 'function') {
        onChange(e);
      }
    };
    this.handleKeyDown = e => {
      if (this.props.variant === 'toggle' && e.keyCode === _keycode.default.codes.enter) {
        this._input && this._input.click();
        e.preventDefault();
      }
    };
    this.handleFocus = () => {
      this.setState({
        focused: true
      });
    };
    this.handleBlur = () => {
      this.setState({
        focused: false
      });
    };
    this.handleMouseOver = () => {
      !this.props.disabled && this.setState({
        hovered: true
      });
    };
    this.handleMouseOut = () => {
      this.setState({
        hovered: false
      });
    };
    this.state = {
      focused: false,
      hovered: false,
      checked: typeof props.checked === 'undefined' ? !!props.defaultChecked : void 0
    };
    if (typeof props.checked === 'undefined') {
      // @ts-expect-error ts-migrate(2339) FIXME: Property 'checked' does not exist on type 'Readonl... Remove this comment to see the full error message
      this.state.checked = !!props.defaultChecked;
    }
    this._defaultId = props.deterministicId();
  }
  componentDidMount() {
    var _this$props$makeStyle, _this$props2;
    if (this._input) {
      this._input.indeterminate = this.props.indeterminate;
    }
    (_this$props$makeStyle = (_this$props2 = this.props).makeStyles) === null || _this$props$makeStyle === void 0 ? void 0 : _this$props$makeStyle.call(_this$props2);
  }
  componentDidUpdate(prevProps) {
    var _this$props$makeStyle2, _this$props3;
    if (prevProps.indeterminate !== this.props.indeterminate && this._input) {
      this._input.indeterminate = this.props.indeterminate || false;
    }
    (_this$props$makeStyle2 = (_this$props3 = this.props).makeStyles) === null || _this$props$makeStyle2 === void 0 ? void 0 : _this$props$makeStyle2.call(_this$props3);
  }
  get id() {
    return this.props.id || this._defaultId;
  }
  get checked() {
    return typeof this.props.checked === 'undefined' ? this.state.checked : this.props.checked;
  }
  get focused() {
    return (0, _isActiveElement.isActiveElement)(this._input);
  }
  get isNewError() {
    var _this$props$messages;
    return !!((_this$props$messages = this.props.messages) !== null && _this$props$messages !== void 0 && _this$props$messages.find(m => m.type === 'newError'));
  }
  get invalid() {
    var _this$props$messages2;
    return !!((_this$props$messages2 = this.props.messages) !== null && _this$props$messages2 !== void 0 && _this$props$messages2.find(m => m.type === 'newError' || m.type === 'error'));
  }
  focus() {
    this._input && this._input.focus();
  }
  renderFacade() {
    const _this$props4 = this.props,
      size = _this$props4.size,
      disabled = _this$props4.disabled,
      variant = _this$props4.variant,
      label = _this$props4.label,
      readOnly = _this$props4.readOnly,
      indeterminate = _this$props4.indeterminate,
      labelPlacement = _this$props4.labelPlacement,
      themeOverride = _this$props4.themeOverride,
      isRequired = _this$props4.isRequired,
      styles = _this$props4.styles;
    const _this$state = this.state,
      hovered = _this$state.hovered,
      focused = _this$state.focused;
    (0, _console.logError)(!(variant === 'simple' && labelPlacement !== 'end'), `[Checkbox] The \`simple\` variant does not support the \`labelPlacement\` property.  Use the \`toggle\` variant instead.`);
    if (variant === 'toggle') {
      return (0, _jsxRuntime.jsxs)(_ToggleFacade.ToggleFacade, {
        disabled: disabled,
        size: size,
        focused: focused,
        checked: this.checked,
        readOnly: readOnly,
        labelPlacement: labelPlacement,
        themeOverride: themeOverride,
        invalid: this.invalid,
        children: [label, isRequired && label && (0, _jsxRuntime.jsxs)("span", {
          css: this.invalid ? styles === null || styles === void 0 ? void 0 : styles.requiredInvalid : {},
          "aria-hidden": true,
          children: [' ', "*"]
        })]
      });
    } else {
      return (0, _jsxRuntime.jsxs)(_CheckboxFacade.CheckboxFacade, {
        size: size,
        hovered: hovered,
        focused: focused,
        checked: this.checked,
        indeterminate: indeterminate,
        themeOverride: themeOverride,
        invalid: this.invalid,
        children: [label, isRequired && label && (0, _jsxRuntime.jsxs)("span", {
          css: this.invalid ? styles === null || styles === void 0 ? void 0 : styles.requiredInvalid : {},
          "aria-hidden": true,
          children: [' ', "*"]
        })]
      });
    }
  }
  renderMessages() {
    const _this$props5 = this.props,
      messages = _this$props5.messages,
      styles = _this$props5.styles,
      variant = _this$props5.variant;
    return messages && messages.length > 0 ? (0, _jsxRuntime.jsx)(_View.View, {
      display: "block",
      margin: "small 0 0",
      css: this.isNewError && (variant === 'toggle' ? styles === null || styles === void 0 ? void 0 : styles.indentedToggleError : styles === null || styles === void 0 ? void 0 : styles.indentedError),
      children: (0, _jsxRuntime.jsx)(_FormFieldMessages.FormFieldMessages, {
        messages: messages
      })
    }) : null;
  }
  render() {
    const _this$props6 = this.props,
      disabled = _this$props6.disabled,
      readOnly = _this$props6.readOnly,
      value = _this$props6.value,
      onKeyDown = _this$props6.onKeyDown,
      onFocus = _this$props6.onFocus,
      onBlur = _this$props6.onBlur,
      onMouseOver = _this$props6.onMouseOver,
      onMouseOut = _this$props6.onMouseOut,
      indeterminate = _this$props6.indeterminate,
      variant = _this$props6.variant,
      styles = _this$props6.styles,
      isRequired = _this$props6.isRequired;
    const props = (0, _omitProps.omitProps)(this.props, Checkbox.allowedProps);
    (0, _console.logError)(!(variant === 'toggle' && indeterminate), `[Checkbox] The \`toggle\` variant does not support the \`indeterminate\` property. Use the \`simple\` variant instead.`);
    return (0, _jsxRuntime.jsx)("div", {
      css: styles === null || styles === void 0 ? void 0 : styles.checkbox
      /* eslint-disable-next-line jsx-a11y/mouse-events-have-key-events */,
      onMouseOver: (0, _createChainedFunction.createChainedFunction)(onMouseOver, this.handleMouseOver)
      /* eslint-disable-next-line jsx-a11y/mouse-events-have-key-events */,
      onMouseOut: (0, _createChainedFunction.createChainedFunction)(onMouseOut, this.handleMouseOut),
      ref: this.handleRef,
      children: (0, _jsxRuntime.jsxs)("div", {
        css: styles === null || styles === void 0 ? void 0 : styles.container,
        children: [(0, _jsxRuntime.jsx)("input", {
          ...props,
          id: this.id,
          value: value,
          type: "checkbox",
          ref: c => {
            this._input = c;
          },
          required: isRequired,
          disabled: disabled || readOnly,
          "aria-checked": indeterminate ? 'mixed' : void 0,
          css: styles === null || styles === void 0 ? void 0 : styles.input,
          onChange: this.handleChange,
          onKeyDown: (0, _createChainedFunction.createChainedFunction)(onKeyDown, this.handleKeyDown),
          onFocus: (0, _createChainedFunction.createChainedFunction)(onFocus, this.handleFocus),
          onBlur: (0, _createChainedFunction.createChainedFunction)(onBlur, this.handleBlur),
          checked: this.checked
        }), (0, _jsxRuntime.jsxs)("label", {
          htmlFor: this.id,
          css: styles === null || styles === void 0 ? void 0 : styles.control,
          children: [this.renderFacade(), this.renderMessages()]
        })]
      })
    });
  }
}, _Checkbox.displayName = "Checkbox", _Checkbox.componentId = 'Checkbox', _Checkbox.propTypes = _props.propTypes, _Checkbox.allowedProps = _props.allowedProps, _Checkbox.defaultProps = {
  size: 'medium',
  variant: 'simple',
  disabled: false,
  inline: false,
  indeterminate: false,
  readOnly: false,
  labelPlacement: 'end'
}, _Checkbox)) || _class) || _class) || _class);
var _default = exports.default = Checkbox;