"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault").default;
var _react = require("@testing-library/react");
var _vitest = require("vitest");
var _userEvent = _interopRequireDefault(require("@testing-library/user-event"));
require("@testing-library/jest-dom");
var _runAxeCheck = require("@instructure/ui-axe-check/lib/runAxeCheck.js");
var _index = require("../index");
var _Checkbox3 = require("../../Checkbox");
var _jsxRuntime = require("@emotion/react/jsx-runtime");
var _Checkbox, _Checkbox2;
/*
 * The MIT License (MIT)
 *
 * Copyright (c) 2015 - present Instructure, Inc.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
const TEST_NAME = 'test-name';
const TEST_DESCRIPTION = 'test-description';
const TEST_ERROR_MESSAGE = 'test-error-message';
const TEST_VALUE_1 = 'test-value-1';
const TEST_VALUE_2 = 'test-value-2';
const TEST_LABEL_1 = 'test-label-1';
const TEST_LABEL_2 = 'test-label-2';
const renderCheckboxGroup = props => {
  const allProps = {
    name: TEST_NAME,
    description: TEST_DESCRIPTION,
    ...props
  };
  return (0, _react.render)((0, _jsxRuntime.jsxs)(_index.CheckboxGroup, {
    ...allProps,
    children: [_Checkbox || (_Checkbox = (0, _jsxRuntime.jsx)(_Checkbox3.Checkbox, {
      label: TEST_LABEL_1,
      value: TEST_VALUE_1
    })), _Checkbox2 || (_Checkbox2 = (0, _jsxRuntime.jsx)(_Checkbox3.Checkbox, {
      label: TEST_LABEL_2,
      value: TEST_VALUE_2
    }))]
  }));
};
describe('<CheckboxGroup />', () => {
  let consoleWarningMock;
  let consoleErrorMock;
  beforeEach(() => {
    // Mocking console to prevent test output pollution
    consoleWarningMock = _vitest.vi.spyOn(console, 'warn').mockImplementation(() => {});
    consoleErrorMock = _vitest.vi.spyOn(console, 'error').mockImplementation(() => {});
  });
  afterEach(() => {
    consoleWarningMock.mockRestore();
    consoleErrorMock.mockRestore();
  });
  it('adds the name props to all Checkbox types', () => {
    renderCheckboxGroup({
      name: TEST_NAME
    });
    const checkboxes = _react.screen.getAllByRole('checkbox');
    expect(checkboxes.length).toBe(2);
    expect(checkboxes[0]).toHaveAttribute('name', TEST_NAME);
    expect(checkboxes[1]).toHaveAttribute('name', TEST_NAME);
  });
  it('links the messages to the fieldset via aria-describedby', () => {
    const _renderCheckboxGroup = renderCheckboxGroup({
        messages: [{
          text: TEST_ERROR_MESSAGE,
          type: 'error'
        }]
      }),
      container = _renderCheckboxGroup.container;
    const group = _react.screen.getByRole('group');
    const ariaDesc = group.getAttribute('aria-describedby');
    const messageById = container.querySelector(`[id="${ariaDesc}"]`);
    expect(messageById).toBeInTheDocument();
    expect(messageById).toHaveTextContent(TEST_ERROR_MESSAGE);
  });
  it('displays description message inside the legend', () => {
    const _renderCheckboxGroup2 = renderCheckboxGroup({
        description: TEST_DESCRIPTION
      }),
      container = _renderCheckboxGroup2.container;
    const legend = container.querySelector('span[class$="-formFieldLayout__label"]');
    expect(legend).toBeInTheDocument();
    expect(legend).toHaveTextContent(TEST_DESCRIPTION);
  });
  it('does not call the onChange prop when disabled', async () => {
    const onChange = _vitest.vi.fn();
    renderCheckboxGroup({
      onChange,
      disabled: true
    });
    const checkboxElement = _react.screen.getAllByRole('checkbox')[0];
    _react.fireEvent.click(checkboxElement);
    await (0, _react.waitFor)(() => {
      expect(onChange).not.toHaveBeenCalled();
      expect(checkboxElement).toBeDisabled();
    });
  });
  it('does not call the onChange prop when readOnly', async () => {
    const onChange = _vitest.vi.fn();
    renderCheckboxGroup({
      onChange,
      readOnly: true
    });
    const checkboxElement = _react.screen.getAllByRole('checkbox')[0];
    _react.fireEvent.click(checkboxElement);
    await (0, _react.waitFor)(() => {
      expect(onChange).not.toHaveBeenCalled();
      expect(checkboxElement).toBeDisabled();
    });
  });
  it('should not update the value when the value prop is set', async () => {
    const onChange = _vitest.vi.fn();
    renderCheckboxGroup({
      onChange,
      value: ['tester']
    });
    const checkboxes = _react.screen.getAllByRole('checkbox');
    expect(checkboxes[0]).not.toBeChecked();
    expect(checkboxes[1]).not.toBeChecked();
    _userEvent.default.click(checkboxes[0]);
    await (0, _react.waitFor)(() => {
      expect(onChange).not.toHaveBeenCalled();
      expect(checkboxes[0]).not.toBeChecked();
      expect(checkboxes[1]).not.toBeChecked();
    });
  });
  it('should add the checkbox value to the value list when it is checked', async () => {
    const onChange = _vitest.vi.fn();
    renderCheckboxGroup({
      onChange
    });
    const checkboxes = _react.screen.getAllByRole('checkbox');
    expect(checkboxes[0]).not.toBeChecked();
    expect(checkboxes[1]).not.toBeChecked();
    _userEvent.default.click(checkboxes[0]);
    _userEvent.default.click(checkboxes[1]);
    await (0, _react.waitFor)(() => {
      expect(checkboxes[0]).toBeChecked();
      expect(checkboxes[1]).toBeChecked();
      expect(onChange).toHaveBeenCalledWith([TEST_VALUE_1, TEST_VALUE_2]);
    });
  });
  it('should check the checkboxes based on the defaultValue prop', () => {
    const defaultValue = [TEST_VALUE_2];
    renderCheckboxGroup({
      defaultValue
    });
    const checkboxes = _react.screen.getAllByRole('checkbox');
    expect(checkboxes[0]).not.toBeChecked();
    expect(checkboxes[1]).toBeChecked();
  });
  it('should remove the checkbox value from the value list when it is unchecked', async () => {
    const onChange = _vitest.vi.fn();
    const defaultValue = [TEST_VALUE_1, TEST_VALUE_2];
    renderCheckboxGroup({
      onChange,
      defaultValue
    });
    const checkboxes = _react.screen.getAllByRole('checkbox');
    expect(checkboxes[0]).toBeChecked();
    expect(checkboxes[1]).toBeChecked();
    _userEvent.default.click(checkboxes[0]);
    await (0, _react.waitFor)(() => {
      expect(checkboxes[0]).not.toBeChecked();
      expect(checkboxes[1]).toBeChecked();
      expect(onChange).toHaveBeenCalledWith([TEST_VALUE_2]);
    });
  });
  it('passes the array of selected values to onChange handler', async () => {
    const onChange = _vitest.vi.fn();
    const defaultValue = [TEST_VALUE_2];
    renderCheckboxGroup({
      onChange,
      defaultValue
    });
    const checkboxes = _react.screen.getAllByRole('checkbox');
    expect(checkboxes[0]).not.toBeChecked();
    expect(checkboxes[1]).toBeChecked();
    _userEvent.default.click(checkboxes[0]);
    await (0, _react.waitFor)(() => {
      expect(checkboxes[0]).toBeChecked();
      expect(checkboxes[1]).toBeChecked();
      expect(onChange).toHaveBeenCalledWith([TEST_VALUE_2, TEST_VALUE_1]);
    });
  });
  describe('for a11y', () => {
    it('should meet standards', async () => {
      const _renderCheckboxGroup3 = renderCheckboxGroup(),
        container = _renderCheckboxGroup3.container;
      const axeCheck = await (0, _runAxeCheck.runAxeCheck)(container);
      expect(axeCheck).toBe(true);
    });
    it('adds the correct ARIA attributes', () => {
      const _renderCheckboxGroup4 = renderCheckboxGroup({
          disabled: true,
          messages: [{
            type: 'newError',
            text: 'abc'
          }],
          // @ts-ignore This is a valid attribute
          'data-id': 'group'
        }),
        container = _renderCheckboxGroup4.container;
      const group = container.querySelector(`[data-id="group"]`);
      expect(group).toBeInTheDocument();
      expect(group).toHaveAttribute('aria-disabled', 'true');
      // ARIA role 'group' cannot have the 'aria-invalid' attribute
      expect(group).not.toHaveAttribute('aria-invalid');
    });
  });
});